@@ -1,5 +1,5 @@
 __name__ = "socket_api2"
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 __author__ = "Da4ndo"
 __discord__ = "Da4ndo#0934"
@@ -232,6 +232,7 @@ class Server():
         port:int, 
         console_output:bool=True,
         client_timeout:int=None,
+        timeout:int=None,
         use_pyngrok:bool = False,
         pyngrok_options:dict = None
     ):
@@ -249,6 +250,7 @@ class Server():
         self.PORT = port
         self.console_output = console_output
         self.client_timeout = client_timeout
+        self.timeout = timeout
 
         self.decorator_functions_call = []
         self.decorator_client_disconnect = []
@@ -260,6 +262,7 @@ class Server():
         self.server = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
         self.server.bind((self.IP, self.PORT))
         self.server.listen(1)
+        self.server.settimeout(self.timeout)
         
         if self.use_pyngrok: self.PUBLIC_URL = ngrok.connect(self.PORT, self.pyngrok_options.get("mode", "tcp"), options={"remote_addr": "{}:{}".format(self.IP, self.PORT)})
 
